@@ -2,7 +2,7 @@ class SqlException(Exception):
     pass
 
 
-class ExistException(Exception):
+class NoExistException(Exception):
     """对象不存在"""
     pass
 
@@ -10,3 +10,8 @@ class ExistException(Exception):
 class FetchRowsException(Exception):
     """影响行数异常"""
     pass
+
+
+class EntityException(Exception):
+    """实体对象错误"""
+    pass
